#!/usr/bin/env python

#-------------------------------------------------------------------------#
#
# This python script produces all the figures in the manuscript. 
# It requires NetCDF output files and the Scientific and numpy python 
# modules installed. 
#
# Copyright (C) 2009 David McInerney, University of Chicago
#
#-------------------------------------------------------------------------
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program (see file "COPYING").  If not, see 
#    <http://www.gnu.org/licenses/>.
#
#-------------------------------------------------------------------------

from matplotlib import rc, rcParams
from pylab import figure, subplot, hold, quiver, text, savefig, fill, plot, show,  \
     axis, title, xlabel, ylabel, title, xticks, yticks, legend, axes, find, \
     quiverkey, contour, clabel
from numpy import min, max, array, size, zeros, shape, transpose, repeat, \
     arange, fromfile
from mpl_toolkits.basemap import NetCDFFile
#from Scientific.IO.NetCDF import NetCDFFile
from dm_functions import subplot_3

fig_num = 0
inch_per_cm = 1./2.54

rcParams['legend.fontsize'] = 'medium'

# select location of NetCDF files
# online appendix netcdf files  
#fname_1 = '../Output/McInerney_at_al_CF_output_T1_56_40_8000.nc'
#fname_2 = '../Output/McInerney_at_al_CF_output_T2_56_40_8000.nc'
#fname_3 = '../Output/McInerney_at_al_CF_output_T3_56_40_8000.nc'
# output from fortran code 
#fname_1 = '../Output/Manuscript/Test1/28_20_2000/output.nc'
#fname_2 = '../Output/Manuscript/Test2/28_20_2000/output.nc'
#fname_3 = '../Output/Manuscript/Test3/28_20_2000/output.nc'
fname_1 = '../Output/Manuscript/Test1/56_40_8000/output.nc'
fname_2 = '../Output/Manuscript/Test2/56_40_8000/output.nc'
fname_3 = '../Output/Manuscript/Test3/56_40_8000/output.nc'
#fname_1 = '../Output/Manuscript/Test1/140_100_50000/output.nc'
#fname_2 = '../Output/Manuscript/Test2/140_100_50000/output.nc'
#fname_3 = '../Output/Manuscript/Test3/140_100_50000/output.nc'

# open netcdf files
f1 = NetCDFFile(fname_1)
f2 = NetCDFFile(fname_2)
f3 = NetCDFFile(fname_3)

# read in grid variables
x_at_zeta = f1.variables['x_at_zeta'][:]
y_at_zeta = f1.variables['y_at_zeta'][:]
x_at_u = f1.variables['x_at_u'][:]
y_at_u = f1.variables['y_at_u'][:]
time = f1.variables['time'][:]
 
# calculate grid size
JJ = size(x_at_zeta)
KK = size(y_at_zeta)
NN = size(time)

##################################################################
# figure displaying lake, wind stress, etc

# set the dimensions of the lake
LL = 14e3
BB = 10e3

# set the boundary coordinates
boundary = array([[0, LL, LL, 0, 0],[0, 0, BB, BB, 0]])

# the following lines are required for plotting the lake in fig 1 and 2
border_x = BB/10.
border_y = BB/10.

outer_boundary = boundary + [ [-border_x, border_x, border_x, -border_x, -border_x], 
				[ -border_y, -border_y, border_y, border_y, -border_y] ]

upper_box = array( [ [ -border_x, LL+border_x, LL+border_x, -border_x, -border_x] , \
		[ BB, BB, BB+border_y, BB+border_y, BB] ] )
lower_box = array( [ [ -border_x, LL+border_x, LL+border_x, -border_x, -border_x] , \
                [ 0, 0, -border_y, -border_y, 0] ] )
left_box = array( [ [ -border_x, 0, 0, -border_x, -border_x], 
			[ -border_y, -border_y, BB+border_y, BB+border_y, -border_y] ] )
right_box = array( [ [ LL, LL+border_x, LL+border_x, LL, LL], 
                        [ -border_y, -border_y, BB+border_y, BB+border_y, -border_y] ] )

min_x = min(outer_boundary[0,:])
max_x = max(outer_boundary[0,:])
min_y = min(outer_boundary[1,:])
max_y = max(outer_boundary[1,:])

offset = 200

width = 10*inch_per_cm
height = (max_y-min_y)/(max_x-min_x)*width

fig_num = fig_num+1
figure(fig_num, figsize=(width,height))

plot(boundary[0,:],boundary[1,:],'k')
hold('True')
fill(upper_box[0,:],upper_box[1,:],fc=[0.7,0.7,0.7],ec=[0.7,0.7,0.7])
fill(lower_box[0,:],lower_box[1,:],fc=[0.7,0.7,0.7],ec=[0.7,0.7,0.7])
fill(left_box[0,:],left_box[1,:],fc=[0.7,0.7,0.7],ec=[0.7,0.7,0.7])
fill(right_box[0,:],right_box[1,:],fc=[0.7,0.7,0.7],ec=[0.7,0.7,0.7])
quiver([2000,2000],[2000,2000],[0,1],[1,0],scale=4)
text(3500,2000-offset,r'$x$',horizontalalignment='center',verticalalignment='top', \
	fontsize=12)
text(2000-offset,3500,r'$y$',horizontalalignment='right',verticalalignment='center', \
	fontsize=12)
quiver([9000],[5500],[1],[0.8],scale=6,width=0.004)
plot([9000,12000],[5500,5500],'k:')
text(10000,5700,r'$\alpha$',style='italic',fontsize=12)
text(12000+offset/2,8000+offset/2,r'$\tau_s$',style='italic',fontsize=12,weight='bold')

text(0,-border_y-offset,r'$x = 0$',horizontalalignment='center',verticalalignment='top', style='italic',fontsize=12)
text(14000,-border_y-offset,r'$x = l$',horizontalalignment='center',verticalalignment='top', style='italic',fontsize=12)
text(-border_x-offset,0,r'$y = 0$',horizontalalignment='right',verticalalignment='center', style='italic',fontsize=12)
text(-border_x-offset,10000,r'$y = b$',horizontalalignment='right',verticalalignment='center',style='italic',fontsize=12)

axis('off')
savefig('Figures/Fig_01.eps',dpi=300)

#########################################################################
# figure displaying points A-F

# select points where variables are plotted
x_index_num = [JJ/7-1, 2*JJ/7-1, 3*JJ/7-1, JJ/7-1, JJ/2, JJ/2]
y_index_num = [JJ/7-1, 2*JJ/7-1, 3*JJ/7-1, 4*JJ/7-1, 1-1, KK/2-1]

fig_num = fig_num+1
figure(fig_num, figsize=(width,height))

plot(boundary[0,:],boundary[1,:],'k')
hold('True')
fill(upper_box[0,:],upper_box[1,:],fc=[0.7,0.7,0.7],ec=[0.7,0.7,0.7])
fill(lower_box[0,:],lower_box[1,:],fc=[0.7,0.7,0.7],ec=[0.7,0.7,0.7])
fill(left_box[0,:],left_box[1,:],fc=[0.7,0.7,0.7],ec=[0.7,0.7,0.7])
fill(right_box[0,:],right_box[1,:],fc=[0.7,0.7,0.7],ec=[0.7,0.7,0.7])
plot(x_at_zeta[x_index_num[0:4]],y_at_zeta[y_index_num[0:4]],'k+')
plot([x_at_u[x_index_num[4]]-offset,x_at_u[x_index_num[4]]+offset],[y_at_u[y_index_num[4]],y_at_u[y_index_num[4]]],'k-')
plot([x_at_u[x_index_num[5]]-offset,x_at_u[x_index_num[5]]+offset],[y_at_u[y_index_num[5]],y_at_u[y_index_num[5]]],'k-')
text(x_at_zeta[x_index_num[0]]+2*offset,y_at_zeta[y_index_num[0]],r'$\rm{A}$',horizontalalignment='left', \
        verticalalignment='center',fontsize=12)
text(x_at_zeta[x_index_num[1]]+2*offset,y_at_zeta[y_index_num[1]],r'$\rm{B}$',horizontalalignment='left', \
	verticalalignment='center',fontsize=12)
text(x_at_zeta[x_index_num[2]]+2*offset,y_at_zeta[y_index_num[2]],r'$\rm{C}$',horizontalalignment='left', \
	verticalalignment='center',fontsize=12)
text(x_at_zeta[x_index_num[3]]+2*offset,y_at_zeta[y_index_num[3]],r'$\rm{D}$',horizontalalignment='left', \
	verticalalignment='center',fontsize=12)
text(x_at_u[x_index_num[4]]+2*offset,y_at_u[y_index_num[4]],r'$\rm{E}$',horizontalalignment='left', \
	verticalalignment='bottom',fontsize=12)
text(x_at_u[x_index_num[5]]+2*offset,y_at_u[y_index_num[5]],r'$\rm{F}$',horizontalalignment='left', \
	verticalalignment='top',fontsize=12)

plot([0,LL],[BB/2,BB/2],'k:')
plot([LL/2,LL/2],[0,BB],'k:')

text(0,-border_y-offset,r'$x = 0$',horizontalalignment='center',verticalalignment='top', \
	style='italic',fontsize=12)
text(7000,-border_y-offset,r'$x = l/2$',horizontalalignment='center',verticalalignment='top', \
	style='italic',fontsize=12)
text(14000,-border_y-offset,r'$x = l$',horizontalalignment='center',verticalalignment='top', \
	style='italic',fontsize=12)
text(-border_x-offset,0,r'$y = 0$',horizontalalignment='right',verticalalignment='center', \
	style='italic',fontsize=12)
text(-border_x-offset,5000,r'$y = b/2$',horizontalalignment='right',verticalalignment='center', \
	style='italic',fontsize=12)
text(-border_x-offset,10000,r'$y = b$',horizontalalignment='right',verticalalignment='center', \
	style='italic',fontsize=12)

axis('off')

savefig('Figures/Fig_04.eps',dpi=300)

###########################################################################

zeta1_t1 = f1.variables['Analytic_zeta1'][:,:,:]
zeta_anal_t1 = f1.variables['Analytic_zeta'][:,:,:]
zeta_num_t1 = f1.variables['Numerical_zeta'][:,:,:]

zeta1_t2 = f2.variables['Analytic_zeta1'][:,:,:]
zeta_anal_t2 = f2.variables['Analytic_zeta'][:,:,:]
zeta_num_t2 = f2.variables['Numerical_zeta'][:,:,:]

zeta1_t3 = f3.variables['Analytic_zeta1'][:,:,:]
zeta_anal_t3 = f3.variables['Analytic_zeta'][:,:,:]
zeta_num_t3 = f3.variables['Numerical_zeta'][:,:,:]

u1_t1 = f1.variables['Analytic_U1'][:,:,:]
u_anal_t1 = f1.variables['Analytic_U'][:,:,:]
u_num_t1 = f1.variables['Numerical_U'][:,:,:]

u1_t2 = f2.variables['Analytic_U1'][:,:,:]
u_anal_t2 = f2.variables['Analytic_U'][:,:,:]
u_num_t2 = f2.variables['Numerical_U'][:,:,:]

u1_t3 = f3.variables['Analytic_U1'][:,:,:]
u_anal_t3 = f3.variables['Analytic_U'][:,:,:]
u_num_t3 = f3.variables['Numerical_U'][:,:,:]

v1_t2 = f2.variables['Analytic_V1'][:,:,:]
v_anal_t2 = f2.variables['Analytic_V'][:,:,:]
v_num_t2 = f2.variables['Numerical_V'][:,:,:]

u1_at_zeta_t2 = u1_t2[:,1::2,0::2] 
v1_at_zeta_t2 = v1_t2[:,0::2,1::2]

x = f1.variables['x'][:]
y = f1.variables['y'][:]
x_at_zeta = f1.variables['x_at_zeta'][:]
y_at_zeta = f1.variables['y_at_zeta'][:]

x_index_anal = zeros((6),'i')
y_index_anal = zeros((6),'i')
for i in range(0,6):
   x_index_anal[i] = find(x==x_at_zeta[x_index_num[i]])
   y_index_anal[i] = find(y==y_at_zeta[y_index_num[i]])
time = f1.variables['time'][:]

t_min = min(time)
t_max = max(time)
t_diff = t_max - t_min

###########################################################################
# plots for Test 1

zeta_min = -0.45
zeta_max = 0.45

width = 20.*inch_per_cm
height = width

fig_num = fig_num+1
figure(fig_num, figsize=(width,height))

subplot(2,2,1)
plot(time,zeta1_t1[:,y_index_anal[0],x_index_anal[0]],'k:')
hold('True')
plot(time,zeta_anal_t1[:,y_index_anal[0],x_index_anal[0]],'k--')
plot(time,zeta_num_t1[:,y_index_num[0],x_index_num[0]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.4,-0.2,0,0.2,0.4])
ylabel(r'$\rm{Elevation (m)}$')
title(r'$\rm{Position}\;\rm{A}$')

##################

subplot(2,2,2)
plot(time,zeta1_t1[:,y_index_anal[1],x_index_anal[1]],'k:')
hold('True')
plot(time,zeta_anal_t1[:,y_index_anal[1],x_index_anal[1]],'k--')
plot(time,zeta_num_t1[:,y_index_num[1],x_index_num[1]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.4,-0.2,0,0.2,0.4])
title(r'$\rm{Position}\;\rm{B}$')

##################

subplot(2,2,3)
plot(time,zeta1_t1[:,y_index_anal[2],x_index_anal[2]],'k:')
hold('True')
plot(time,zeta_anal_t1[:,y_index_anal[2],x_index_anal[2]],'k--')
plot(time,zeta_num_t1[:,y_index_num[2],x_index_num[2]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.4,-0.2,0,0.2,0.4])
xlabel(r'$\rm{Time (s)}$')
ylabel(r'$\rm{Elevation (m)}$')
title(r'$\rm{Position}\;\rm{C}$')

##################

subplot(2,2,4)
plot(time,zeta1_t1[:,y_index_anal[3],x_index_anal[3]],'k:')
hold('True')
plot(time,zeta_anal_t1[:,y_index_anal[3],x_index_anal[3]],'k--')
plot(time,zeta_num_t1[:,y_index_num[3],x_index_num[3]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.4,-0.2,0,0.2,0.4])
xlabel(r'$\rm{Time (s)}$')
title(r'$\rm{Position}\;\rm{D}$')
legend((r'$\rm{1st-order}$',r'$\rm{2nd-order}$',r'$\rm{Numerical}$'),loc='lower right',labelspacing=0.05)

savefig('Figures/Fig_05.eps',dpi=300)

#############################################

width = 20.*inch_per_cm
height = 10.*inch_per_cm

fig_num = fig_num+1
figure(fig_num,(width,height))

u_min = -1
u_max = 0.65

axes([0.13,0.15,0.35,0.72])
plot(time,u1_t1[:,y_index_anal[4],x_index_anal[4]],'k:')
hold('True')
plot(time,u_anal_t1[:,y_index_anal[4],x_index_anal[4]],'k--')
plot(time,u_num_t1[:,y_index_num[4],x_index_num[4]],'k-')
axis([t_min,t_max,u_min,u_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.75,-0.5,-0.25,0,0.25,0.5])
xlabel(r'$\rm{Time (s)}$',verticalalignment='top')
ylabel(r'$q_x \rm{(m}^2\rm{s}^{-1}\rm{)}$')
title(r'$\rm{Position}\;\rm{E}$')

###############

axes([0.6,0.15,0.35,0.72])
plot(time,u1_t1[:,y_index_anal[5],x_index_anal[5]],'k:')
hold('True')
plot(time,u_anal_t1[:,y_index_anal[5],x_index_anal[5]],'k--')
plot(time,u_num_t1[:,y_index_num[5],x_index_num[5]],'k-')
axis([t_min,t_max,u_min,u_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.75,-0.5,-0.25,0,0.25,0.5])
xlabel(r'$\rm{Time (s)}$')
title(r'$\rm{Position}\;\rm{F}$')
legend((r'$\rm{1st-order}$',r'$\rm{2nd-order}$',r'$\rm{Numerical}$'),loc='lower right',labelspacing=0.05)

savefig('Figures/Fig_08.eps',dpi=300)

##############################################
# plots for Test 2

zeta_min = -0.25
zeta_max = 0.25

width = 20.*inch_per_cm
height = width

fig_num = fig_num+1
figure(fig_num,(width,height))

subplot(2,2,1)
plot(time,zeta1_t2[:,y_index_anal[0],x_index_anal[0]],'k:')
hold('True') 
plot(time,zeta_anal_t2[:,y_index_anal[0],x_index_anal[0]],'k--')
plot(time,zeta_num_t2[:,y_index_num[0],x_index_num[0]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.2,-0.1,0,0.1,0.2])
ylabel(r'$\rm{Elevation (m)}$')
title(r'$\rm{Position}\;\rm{A}$')

###########

subplot(2,2,2)
plot(time,zeta1_t2[:,y_index_anal[1],x_index_anal[1]],'k:')
hold('True')
plot(time,zeta_anal_t2[:,y_index_anal[1],x_index_anal[1]],'k--')
plot(time,zeta_num_t2[:,y_index_num[1],x_index_num[1]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.2,-0.1,0,0.1,0.2])
title(r'$\rm{Position}\;\rm{B}$')

################

subplot(2,2,3)
plot(time,zeta1_t2[:,y_index_anal[2],x_index_anal[2]],'k:')
hold('True')
plot(time,zeta_anal_t2[:,y_index_anal[2],x_index_anal[2]],'k--')
plot(time,zeta_num_t2[:,y_index_num[2],x_index_num[2]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.2,-0.1,0,0.1,0.2])
xlabel(r'$\rm{Time (s)}$')
ylabel(r'$\rm{Elevation (m)}$')
title(r'$\rm{Position}\;\rm{C}$')

################

subplot(2,2,4)
plot(time,zeta1_t2[:,y_index_anal[3],x_index_anal[3]],'k:')
hold('True') 
plot(time,zeta_anal_t2[:,y_index_anal[3],x_index_anal[3]],'k--')
plot(time,zeta_num_t2[:,y_index_num[3],x_index_num[3]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.2,-0.1,0,0.1,0.2])
xlabel(r'$\rm{Time (s)}$')
title(r'$\rm{Position}\;\rm{D}$')
legend((r'${\rm 1st-order}$',r'${\rm 2nd-order}$',r'${\rm Numerical}$'),loc='lower right',labelspacing=0.05)

savefig('Figures/Fig_06.eps',dpi=300)

##############################################

width = 20.*inch_per_cm
height = 10.*inch_per_cm

fig_num = fig_num+1
figure(fig_num,(width,height))

u_min = -0.5
u_max = 0.5

axes([0.13,0.15,0.35,0.72])
plot(time,u1_t2[:,y_index_anal[4],x_index_anal[4]],'k:')
hold('True')
plot(time,u_anal_t2[:,y_index_anal[4],x_index_anal[4]],'k--')
plot(time,u_num_t2[:,y_index_num[4],x_index_num[4]],'k-')
axis([t_min,t_max,u_min,u_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.4,-0.2,0,0.2,0.4])
xlabel(r'$\rm{Time (s)}$')
ylabel(r'$q_x \rm{(m}^2\rm{s}^{-1}\rm{)}$')
title(r'$\rm{Position}\;\rm{E}$')

################

axes([0.6,0.15,0.35,0.72])
plot(time,u1_t2[:,y_index_anal[5],x_index_anal[5]],'k:')
hold('True')
plot(time,u_anal_t2[:,y_index_anal[5],x_index_anal[5]],'k--')
plot(time,u_num_t2[:,y_index_num[5],x_index_num[5]],'k-')
axis([t_min,t_max,u_min,u_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.4,-0.2,0,0.2,0.4])
xlabel(r'$\rm{Time (s)}$')
title(r'$\rm{Position}\;\rm{F}$')
legend((r'${\rm 1st-order}$',r'${\rm 2nd-order}$',r'${\rm Numerical}$'),loc='lower right',labelspacing=0.05)

savefig('Figures/Fig_09.eps',dpi=300)

##############################################
# plots for Test 3

zeta_min = -0.08
zeta_max = 0.08

width = 20.*inch_per_cm
height = width

fig_num = fig_num+1
figure(fig_num,(width,height))

subplot(2,2,1)
plot(time,zeta1_t3[:,y_index_anal[0],x_index_anal[0]],'k:')
hold('True') 
plot(time,zeta_anal_t3[:,y_index_anal[0],x_index_anal[0]],'k--')
plot(time,zeta_num_t3[:,y_index_num[0],x_index_num[0]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.08,-0.04,0,0.04,0.08])
ylabel(r'$\rm{Elevation (m)}$')
title(r'$\rm{Position}\;\rm{A}$')

##############m

subplot(2,2,2)
plot(time,zeta1_t3[:,y_index_anal[1],x_index_anal[1]],'k:')
hold('True')
plot(time,zeta_anal_t3[:,y_index_anal[1],x_index_anal[1]],'k--')
plot(time,zeta_num_t3[:,y_index_num[1],x_index_num[1]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.08,-0.04,0,0.04,0.08])
title(r'$\rm{Position}\;\rm{B}$')

################

subplot(2,2,3)
plot(time,zeta1_t3[:,y_index_anal[2],x_index_anal[2]],'k:')
hold('True')
plot(time,zeta_anal_t3[:,y_index_anal[2],x_index_anal[2]],'k--')
plot(time,zeta_num_t3[:,y_index_num[2],x_index_num[2]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.08,-0.04,0,0.04,0.08])
xlabel(r'$\rm{Time (s)}$')
ylabel(r'$\rm{Elevation (m)}$')
title(r'$\rm{Position}\;\rm{C}$')

################

subplot(2,2,4)
plot(time,zeta1_t3[:,y_index_anal[3],x_index_anal[3]],'k:')
hold('True')
plot(time,zeta_anal_t3[:,y_index_anal[3],x_index_anal[3]],'k--')
plot(time,zeta_num_t3[:,y_index_num[3],x_index_num[3]],'k-')
axis([t_min,t_max,zeta_min,zeta_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.08,-0.04,0,0.04,0.08])
xlabel(r'$\rm{Time (s)}$')
title(r'$\rm{Position}\;\rm{D}$')
legend((r'${\rm 1st-order}$',r'${\rm 2nd-order}$',r'${\rm Numerical}$'),loc='lower right',labelspacing=0.05)

savefig('Figures/Fig_07.eps',dpi=300)

#############################################

width = 20.*inch_per_cm
height = 10.*inch_per_cm

fig_num = fig_num+1
figure(fig_num,(width,height))

u_min = -0.15
u_max = 0.15

axes([0.13,0.15,0.35,0.72])
plot(time,u1_t3[:,y_index_anal[4],x_index_anal[4]],'k:')
hold('True')
plot(time,u_anal_t3[:,y_index_anal[4],x_index_anal[4]],'k--')
plot(time,u_num_t3[:,y_index_num[4],x_index_num[4]],'k-')
axis([t_min,t_max,u_min,u_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.15,-0.1,-0.05,0,0.05,0.1,0.15])
xlabel(r'$\rm{Time (s)}$')
ylabel(r'$q_x \rm{(m}^2\rm{s}^{-1}\rm{)}$')
title(r'$\rm{Position}\;\rm{E}$')

################

axes([0.6,0.15,0.35,0.72])
plot(time,u1_t3[:,y_index_anal[5],x_index_anal[5]],'k:')
hold('True')
plot(time,u_anal_t3[:,y_index_anal[5],x_index_anal[5]],'k--')
plot(time,u_num_t3[:,y_index_num[5],x_index_num[5]],'k-')
axis([t_min,t_max,u_min,u_max])
xticks([t_min,t_min+0.5*t_diff,t_max],(r'$0$',r'$0.5T$',r'$T$'))
yticks([-0.15,-0.1,-0.05,0,0.05,0.1,0.15])
xlabel(r'$\rm{Time (s)}$')
title(r'$\rm{Position}\;\rm{F}$')
legend((r'${\rm 1st-order}$',r'${\rm 2nd-order}$',r'${\rm Numerical}$'),loc='lower right',labelspacing=0.05)

savefig('Figures/Fig_10.eps',dpi=300)

##################################################################

v1_t1 = f1.variables['Analytic_V1'][:,:,:]
v_anal_t1 = f1.variables['Analytic_V'][:,:,:]
v_num_t1 = f1.variables['Numerical_V'][:,:,:]
u1_at_zeta_t1 = u1_t1[:,1::2,1::2]
v1_at_zeta_t1 = v1_t1[:,1::2,1::2]
u_anal_at_zeta_t1 = u_anal_t1[:,1::2,1::2]
v_anal_at_zeta_t1 = v_anal_t1[:,1::2,1::2]
x_at_zeta_array = repeat(x_at_zeta,KK).reshape(JJ,KK)
y_at_zeta_array = repeat(y_at_zeta,JJ).reshape(KK,JJ).transpose()

fig_num += 1
width = 15.*inch_per_cm
height = width*10./14*3
figure(fig_num,(width,height))
t_index = size(time)*3./4.

subplot_3(1)
plot(boundary[0,:],boundary[1,:],'k')
hold('True')
q1 = quiver(x_at_zeta_array[2::8,2::8],y_at_zeta_array[2::8,2::8],transpose(u1_at_zeta_t1[t_index,2::8,2::8]), \
            transpose(v1_at_zeta_t1[t_index,2::8,2::8]),color='k',scale=3,width=0.005,headwidth=3,headlength=5)
l1 = plot([0],[0],'k')
q2 = quiver(x_at_zeta_array[2::8,2::8],y_at_zeta_array[2::8,2::8],transpose(u_anal_at_zeta_t1[t_index,2::8,2::8]), \
            transpose(v_anal_at_zeta_t1[t_index,2::8,2::8]),color=[0.7,0.7,0.7],scale=3,width=0.005,headwidth=3,headlength=5)
l2 = plot([0],[0],color=[0.7,0.7,0.7],linewidth=2)
quiverkey(q1,0.6,-0.05,0.25,r'$q_x=0.25\rm{m}^2\rm{s}^{-1}$',labelpos='E')
axis('off')
legend((l1,l2),(r'$\rm{1st-order}$',r'$\rm{2nd-order}$'),loc='lower right',labelspacing=0.05)
text(LL/20.,BB-BB/40.,'(a)',horizontalalignment='center',verticalalignment='top', \
	fontsize=12)

v1_t2 = f2.variables['Analytic_V1'][:,:,:]
v_anal_t2 = f2.variables['Analytic_V'][:,:,:]
v_num_t2 = f2.variables['Numerical_V'][:,:,:]
u1_at_zeta_t2 = u1_t2[:,1::2,1::2]
v1_at_zeta_t2 = v1_t2[:,1::2,1::2]
u_anal_at_zeta_t2 = u_anal_t2[:,1::2,1::2]
v_anal_at_zeta_t2 = v_anal_t2[:,1::2,1::2]
x_at_zeta_array = repeat(x_at_zeta,KK).reshape(JJ,KK)
y_at_zeta_array = repeat(y_at_zeta,JJ).reshape(KK,JJ).transpose()

subplot_3(2)
plot(boundary[0,:],boundary[1,:],'k')
hold('True')
q1 = quiver(x_at_zeta_array[2::8,2::8],y_at_zeta_array[2::8,2::8],transpose(u1_at_zeta_t2[t_index,2::8,2::8]), \
            transpose(v1_at_zeta_t2[t_index,2::8,2::8]),color='k',scale=3,width=0.005,headwidth=3,headlength=5)
l1 = plot([0],[0],'k')
q2 = quiver(x_at_zeta_array[2::8,2::8],y_at_zeta_array[2::8,2::8],transpose(u_anal_at_zeta_t2[t_index,2::8,2::8]), \
            transpose(v_anal_at_zeta_t2[t_index,2::8,2::8]),color=[0.7,0.7,0.7],scale=3,width=0.005,headwidth=3,headlength=5)
l2 = plot([0],[0],color=[0.7,0.7,0.7],linewidth=2)
quiverkey(q1,0.6,-0.05,0.25,r'$q_x=0.25\rm{m}^2\rm{s}^{-1}$',labelpos='E')
axis('off')
legend((l1,l2),(r'$\rm{1st-order}$',r'$\rm{2nd-order}$'),loc='lower right',labelspacing=0.05)
text(LL/20.,BB-BB/40.,'(b)',horizontalalignment='center',verticalalignment='top', \
	fontsize=12)

v1_t3 = f3.variables['Analytic_V1'][:,:,:]
v_anal_t3 = f3.variables['Analytic_V'][:,:,:]
v_num_t3 = f3.variables['Numerical_V'][:,:,:]
u1_at_zeta_t3 = u1_t3[:,1::2,1::2]
v1_at_zeta_t3 = v1_t3[:,1::2,1::2]
u_anal_at_zeta_t3 = u_anal_t3[:,1::2,1::2]
v_anal_at_zeta_t3 = v_anal_t3[:,1::2,1::2]
x_at_zeta_array = repeat(x_at_zeta,KK).reshape(JJ,KK)
y_at_zeta_array = repeat(y_at_zeta,JJ).reshape(KK,JJ).transpose()

subplot_3(3)
plot(boundary[0,:],boundary[1,:],'k')
hold('True')
q1 = quiver(x_at_zeta_array[2::8,2::8],y_at_zeta_array[2::8,2::8],transpose(u1_at_zeta_t3[t_index,2::8,2::8]),transpose(v1_at_zeta_t3[t_index,2::8,2::8]), \
            color='k',scale=1,width=0.005,headwidth=3,headlength=5)
l1 = plot([0],[0],'k')
q2 = quiver(x_at_zeta_array[2::8,2::8],y_at_zeta_array[2::8,2::8],transpose(u_anal_at_zeta_t3[t_index,2::8,2::8]),transpose(v_anal_at_zeta_t3[t_index,2::8,2::8]), \
            color=[0.7,0.7,0.7],scale=1,width=0.005,headwidth=3,headlength=5)
l2 = plot([0],[0],color=[0.7,0.7,0.7],linewidth=2)
quiverkey(q1,0.6,-0.05,0.1,r'$q_x=0.1\rm{m}^2\rm{s}^{-1}$',labelpos='E')
axis('off')
legend((l1,l2),(r'$\rm{1st-order}$',r'$\rm{2nd-order}$'),loc='lower right',labelspacing=0.05)
text(LL/20.,BB-BB/40.,'(c)',horizontalalignment='center',verticalalignment='top', \
	fontsize=12)

savefig('Figures/Fig_03.eps',dpi=300)

##################################################################

import matplotlib
matplotlib.rcParams['xtick.direction'] = 'out'
matplotlib.rcParams['ytick.direction'] = 'out'
matplotlib.rcParams['contour.negative_linestyle'] = 'solid'

width = 15.*inch_per_cm
height = 3*width*10./14.
fig_num += 1
figure(fig_num,(width,height))

zeta1 = f1.variables['Analytic_zeta1'][:,:,:]
zeta_anal = f1.variables['Analytic_zeta'][:,:,:]
x = f1.variables['x'][:]
y = f1.variables['y'][:]

subplot_3(1)
t_index = size(time)*0.5
VV = arange(-0.5,0.5,0.1)
ii = find(abs(VV)<1e-5)
VV[ii] = 1e-7
c1 = contour(x,y,zeta1[t_index,:,:],VV,colors=([0.4,0.4,0.4],),linestyles='dashed')
hold('True')
l1 = plot([0,0],[0,0],color=[0.4,0.4,0.4],linestyle='dashed')
clabel(c1,inline=1,fontsize=8,fmt='%1.1f',colors=([0.4,0.4,0.4],))
hold('True')
c2 = contour(x,y,zeta_anal[t_index,:,:],VV,colors='k')
l2 = plot([0,0],[0,0],'k-')
clabel(c2,inline=1,fontsize=8,fmt='%1.1f')
legend((l1,l2),(r'$\rm{1st-order}$',r'$\rm{2nd-order}$'),loc='lower right',labelspacing=0.05)
plot(boundary[0,:],boundary[1,:],'k',linewidth=2)
axis('off')
text(LL/20.,BB-BB/40.,'(a)',horizontalalignment='center',verticalalignment='top', \
	fontsize=12)

zeta1 = f2.variables['Analytic_zeta1'][:,:,:]
zeta_anal = f2.variables['Analytic_zeta'][:,:,:]

subplot_3(2)
plot(boundary[0,:],boundary[1,:],'k')
t_index = size(time)*0.5
VV = arange(-0.5,0.5,0.05)
ii = find(abs(VV)<1e-5)
VV[ii] = 1e-7
hold('True')
c1 = contour(x,y,zeta1[t_index,:,:],VV,colors=([0.4,0.4,0.4],),linestyles='dashed')
hold('True')
l1 = plot([0,0],[0,0],color=[0.4,0.4,0.4],linestyle='dashed')
clabel(c1,inline=1,fontsize=8,fmt='%1.2f',colors=([0.4,0.4,0.4],),linestyles='dashed')
c2 = contour(x,y,zeta_anal[t_index,:,:],VV,colors='k')
l2 = plot([0,0],[0,0],'k-')
clabel(c2,inline=1,fontsize=8,fmt='%1.2f')
VV = arange(-0.2,0.2,0.05)
legend((l1,l2),(r'$\rm{1st-order}$',r'$\rm{2nd-order}$'),loc='lower right',labelspacing=0.05)
plot(boundary[0,:],boundary[1,:],'k',linewidth=2)
axis('off')
text(LL/20.,BB-BB/40.,'(b)',horizontalalignment='center',verticalalignment='top', \
	fontsize=12)

zeta1 = f3.variables['Analytic_zeta1'][:,:,:]
zeta_anal = f3.variables['Analytic_zeta'][:,:,:]

subplot_3(3)
t_index = size(time)*0.5
VV = arange(-0.1,0.1,0.02)
ii = find(abs(VV)<1e-5)
VV[ii] = 1e-7
c1 = contour(x,y,zeta1[t_index,:,:],VV,colors=([0.4,0.4,0.4],),linestyles='dashed')
hold('True')
l1 = plot([0,0],[0,0],color=[0.4,0.4,0.4],linestyle='dashed')
clabel(c1,inline=1,fontsize=8,fmt='%1.2f',colors=([0.4,0.4,0.4],),linstyles='dashed')
hold('True')
c2 = contour(x,y,zeta_anal[t_index,:,:],VV,colors='k')
l2 = plot([0,0],[0,0],'k-')
clabel(c2,inline=1,fontsize=8,fmt='%1.2f')
plot(boundary[0,:],boundary[1,:],'k',linewidth=2)
legend((l1,l2),(r'$\rm{1st-order}$',r'$\rm{2nd-order}$'),loc='lower right',labelspacing=0.05)
axis('off')
text(LL/10.,BB-BB/40.,'(c)',horizontalalignment='center',verticalalignment='top', \
	fontsize=12)

savefig('Figures/Fig_02.eps',dpi=300)

##################################################################

show()
